@@ -19,12 +19,18 @@ default_UA = "waybackpy python package - https://github.com/akamhy/waybackpy"
 def _archive_url_parser(header):
     """Parse out the archive from header."""
     # Regex1
+    arch = re.search(
+        r"Content-Location: (/web/[0-9]{14}/.*)", str(header)
+    )
+    if arch:
+        return "web.archive.org" + arch.group(1)
+    # Regex2
     arch = re.search(
         r"rel=\"memento.*?(web\.archive\.org/web/[0-9]{14}/.*?)>", str(header)
     )
     if arch:
         return arch.group(1)
-    # Regex2
+    # Regex3
     arch = re.search(r"X-Cache-Key:\shttps(.*)[A-Z]{2}", str(header))
     if arch:
         return arch.group(1)
@@ -134,7 +140,7 @@ class Url:
         data = json.loads(response.read().decode("UTF-8"))
         if not data["archived_snapshots"]:
             raise WaybackError(
-                "'%s' is not yet archived. Use wayback.Url(url, user_agent).save() "
+                "Can not find archive for '%s' try later or use wayback.Url(url, user_agent).save() "
                 "to create a new archive." % self._clean_url()
             )
         archive_url = data["archived_snapshots"]["closest"]["url"]
